# -*- coding: utf-8 -*-
# Author: Arthur Imbert <arthur.imbert.pro@gmail.com>
# License: BSD 3 clause

"""
Unitary tests for bigfish.detection.utils module.
"""

# TODO test bigfish.detection.convert_spot_coordinates
# TODO add test for bigfish.detection.get_object_radius_pixel
# TODO add test for bigfish.detection.get_object_radius_nm
# TODO add test for bigfish.detection.build_reference_spot
# TODO add test for bigfish.detection.get_spot_volume
# TODO add test for bigfish.detection.get_spot_surface
# TODO add test for bigfish.detection.compute_snr_spots
# TODO add test for bigfish.detection.get_breaking_point
